@@ -134,7 +134,8 @@ def warm_volume(base_job, fio_bin):
 
 
 def report_benchmark(api_client, assets, configuration, job_report):
-    for metric, value in [("IOPS", job_report.avg_iops), ("LAT", job_report.avg_lat), ("BW", job_report.avg_bw)]:
+    for metric, value in [("IOPS", job_report.avg_iops), ("LAT", job_report.avg_lat), ("BW", job_report.avg_bw),
+                          ("LAT SD", job_report.stddev_lat), ("BW SD", job_report.stddev_bw)]:
 
         measurement = api_client.measurements.create(
             configuration=configuration,
@@ -246,10 +247,10 @@ def main():
     reporting_endpoint = config.get("reporting", "endpoint")
     reporting_username = config.get("reporting", "username")
     reporting_key = config.get("reporting", "apikey")
-    reporting_retry_max = config.get("reporting", "retry_max")
-    reporting_retry_wait = config.get("reporting", "retry_wait")
 
-    #TODO: Retries
+    # Those two may fail, but that's fine: we haven't daemonized yet.
+    reporting_retry_max = int(config.get("reporting", "retry_max"))
+    reporting_retry_wait = int(config.get("reporting", "retry_wait"))
 
 
     # Final setup options before we daemonize, to let the user catch misconfiguration errors
